@@ -36,9 +36,9 @@ class CDDBModule : public KCModule
 
   public Q_SLOTS:
 
-    void defaults() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void load() Q_DECL_OVERRIDE;
+    void defaults() override;
+    void save() override;
+    void load() override;
 
   protected:
 
